@@ -5,7 +5,7 @@ import logging
 
 from cachecontrol import CacheControl
 
-__version__ = "0.4"
+__version__ = "0.5"
 
 __LONG_SCALE__ = float(0xFFFFFFFFFFFFFFF)
 
@@ -40,12 +40,13 @@ class LDClient(object):
              'User-Agent': 'PythonClient/' + __version__}
         uri = self._config._base_uri + '/api/eval/features/' + key
         r = self._session.get(uri, headers=hdrs, timeout = (self._config._connect, self._config._read))
-        dict = r.json()
-        val = _evaluate(dict, user)
+        r.raise_for_status()
+        hash = r.json()
+        val = _evaluate(hash, user)
         if val is None:
             return default
-        else:
-            return val
+        return val
+        
 
 def _param_for_user(feature, user):
     if 'key' in user:
@@ -105,4 +106,4 @@ def _evaluate(feature, user):
         if param < total:
             return variation['value']
 
-    return False
+    return None
